#ifndef QTMATERIALRIPPLEOVERLAY_H
#define QTMATERIALRIPPLEOVERLAY_H
#include <QtWidgets/QWidget>
#include <QPainterPath>
#include <QSharedPointer>
#include "ndewidgetmaterialripple.h"

namespace NdeWidget
{
//定义窗口基类
class QtMaterialOverlayWidget : public QWidget
{
    Q_OBJECT

public:
    explicit QtMaterialOverlayWidget(QWidget *parent = 0);
    ~QtMaterialOverlayWidget();

protected:
    bool event(QEvent *event) Q_DECL_OVERRIDE;
    bool eventFilter(QObject *obj, QEvent *event) Q_DECL_OVERRIDE;

    virtual QRect overlayGeometry() const;

private:
    Q_DISABLE_COPY(QtMaterialOverlayWidget)
};

//动画显示窗口基类
class QtMaterialRippleOverlay : public QtMaterialOverlayWidget
{
    Q_OBJECT

public:
    explicit QtMaterialRippleOverlay(QWidget *parent = 0);
    ~QtMaterialRippleOverlay();

    //定义添加动画接口
    virtual void addRipple(MaterialRipple *ripple) = 0;

    void removeRipple(MaterialRipple *ripple);

protected:

    inline QList<MaterialRipple *> ripples() const;

private:
    Q_DISABLE_COPY(QtMaterialRippleOverlay)

    //动画效果
    virtual void paintRipple(QPainter *painter, MaterialRipple *ripple) = 0;

protected:
    QList<MaterialRipple *> m_ripples;
};


inline QList<MaterialRipple *> QtMaterialRippleOverlay::ripples() const
{
    return m_ripples;
}

//窗口实现波纹效果
class QtMaterialCircleRippleOverlay : public QtMaterialRippleOverlay
{
    Q_OBJECT
public:
    explicit QtMaterialCircleRippleOverlay(QWidget * parent = 0);
    ~QtMaterialCircleRippleOverlay() {}
    //添加波纹效果动画
    virtual void addRipple(MaterialRipple *ripple);

protected:
    void paintEvent(QPaintEvent *event) Q_DECL_OVERRIDE;
private:
    //实现波纹效果
    virtual void paintRipple(QPainter *painter, MaterialRipple *ripple);
};

}
#endif // QTMATERIALRIPPLEOVERLAY_H
