#ifndef IMAGEITEMWIDGET_H
#define IMAGEITEMWIDGET_H

#include <QWidget>

namespace NdeWidget {

class ImageListItemWidget : public QWidget
{
    Q_OBJECT

    Q_PROPERTY(QString path READ path WRITE setPath NOTIFY pathChanged)
    Q_PROPERTY(QPixmap pixmap READ pixmap WRITE setPixmap NOTIFY pixmapChanged)
    Q_PROPERTY(QString text READ text WRITE setText NOTIFY textChanged)
    Q_PROPERTY(bool textVisible READ textVisible WRITE setTextVisible NOTIFY textVisibleChanged)
    Q_PROPERTY(QSize imageSize READ imageSize WRITE setImageSize NOTIFY imageSizeChanged)
    Q_PROPERTY(bool selected READ selected WRITE setSelected NOTIFY selectedChanged)

public:
    explicit ImageListItemWidget(QWidget *parent = 0);

    QString path() const;
    void setPath(const QString path);
    QPixmap pixmap() const;
    void setPixmap(const QPixmap pixmap);
    QString text() const;
    void setText(const QString text);
    bool textVisible() const;
    void setTextVisible(const bool visible);
    QSize imageSize() const;
    void setImageSize(const QSize size);
    bool selected() const;
    void setSelected(const bool sel);

Q_SIGNALS:
    void pathChanged(QString path);
    void pixmapChanged(QPixmap pixmap);
    void textChanged(QString text);
    void textVisibleChanged(bool visible);
    void imageSizeChanged(QSize size);
    void selectedChanged(bool sel);

protected:
    virtual void paintEvent(QPaintEvent *event);

private:
    QRect getPixmapRect();
    QRect getTextRect();

private:
    bool m_selected;        //是否选中
    QString m_path;         //图片路径
    QString m_text;         //图片名称
    bool m_textVisible;     //名称可见
    QSize m_imageSize;      //图片尺寸
    QPixmap m_pixmap;       //图片

    QMovie * m_loadMovie;   //加载动画，暂时无用
};

}
#endif // IMAGEITEMWIDGET_H
