#ifndef NDESTYLEMATERIALCIRCULARPROGRESS_H
#define NDESTYLEMATERIALCIRCULARPROGRESS_H

#include <QtWidgets/QProgressBar>
#include <QObject>
#include <QtGlobal>
//#include <Nde/MaterialStyle>
#include <QParallelAnimationGroup>

namespace NdeWidget {
namespace Material
{
    enum ProgressType {
        DeterminateProgress,
        IndeterminateProgress
    };
}

class QMaterialCircularProgress : public QProgressBar
{
    Q_OBJECT

    Q_PROPERTY(qreal lineWidth WRITE setLineWidth READ getLineWidth)
    Q_PROPERTY(qreal size WRITE setSize READ getSize)
    Q_PROPERTY(qreal duration WRITE setDuration READ getDuration)

    Q_PROPERTY(qreal dashOffset WRITE setDashOffset READ dashOffset)
    Q_PROPERTY(qreal dashLength WRITE setDashLength READ dashLength)
    Q_PROPERTY(int angle WRITE setAngle READ angle)
private:
    void init();
    void refreshAnimation();
public:
    explicit QMaterialCircularProgress(QWidget *parent = 0);
    ~QMaterialCircularProgress();

    void setProgressType(Material::ProgressType type);
    Material::ProgressType getProgressType() const;

    void setLineWidth(qreal width);
    qreal getLineWidth() const;

    void setSize(int size);
    int getSize() const;

    void setDuration(int duration);
    qreal getDuration() const;

    inline void setDashOffset(qreal offset);
    inline qreal dashOffset() const;

    inline void setDashLength(qreal length);
    inline qreal dashLength() const;

    inline void setAngle(int angle);
    inline int angle() const;

    QSize sizeHint() const Q_DECL_OVERRIDE;



protected:
    void paintEvent(QPaintEvent *event) Q_DECL_OVERRIDE;

private:
    Material::ProgressType              m_progressType;
    qreal                               m_penWidth;
    qreal                               m_duration;
    int                                 m_size;

    qreal                               m_dashOffset;
    qreal                               m_dashLength;
    int                                 m_angle;

    QParallelAnimationGroup *group;
    //Nde::MaterialStyle* m_Style;
};

inline void QMaterialCircularProgress::setDashOffset(qreal offset)
{
    m_dashOffset = offset;
    update();
}

inline qreal QMaterialCircularProgress::dashOffset() const
{
    return m_dashOffset;
}

inline void QMaterialCircularProgress::setDashLength(qreal length)
{
    m_dashLength = length;
    update();
}

inline qreal QMaterialCircularProgress::dashLength() const
{
    return m_dashLength;
}

inline void QMaterialCircularProgress::setAngle(int angle)
{
    m_angle = angle;
    update();
}

inline int QMaterialCircularProgress::angle() const
{
    return m_angle;
}
}


#endif // NDESTYLEMATERIALCIRCULARPROGRESS_H
